/****************************************************************************
 *
 * Rohde&Schwarz NGx Power Supply instrument driver include file
 *
 ****************************************************************************/

#ifndef __RSNGX_HEADER
#define __RSNGX_HEADER

#include "rscore.h"
#include "rsngx_attributes.h"
#include "rsngx_internal.h"
#include "rsngx_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

    /*****************************************************************************
     *- Useful Macros & Constants -----------------------------------------------*
     *****************************************************************************/

#define RSNGX_SIMULATION_ID_QUERY      "Rohde&Schwarz,NGM,123456/789,1.0.10"  /* Default definition of ID Query Response for simulation */
#define RSNGX_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSNGX_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSNGX_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

     /****************************************************************************
      *----------------- Instrument Driver Revision Information -----------------*
      ****************************************************************************/

      /* Class Driver Identification */

#define RSNGX_CLASS_DRIVER_DESCRIPTION           ""
#define RSNGX_CLASS_DRIVER_PREFIX                ""
#define RSNGX_CLASS_DRIVER_VENDOR                ""
#define RSNGX_CLASS_DRIVER_REVISION              ""
#define RSNGX_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSNGX_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSNGX_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSNGX_SPECIFIC_DRIVER_PREFIX             "RSNGX"
#define RSNGX_SPECIFIC_DRIVER_LOCATOR            ""
#define RSNGX_SPECIFIC_DRIVER_VENDOR             ""
#define RSNGX_MAJOR_VERSION                      1L    /* Instrument driver major version          */
#define RSNGX_MINOR_VERSION                      4L    /* Instrument driver minor version          */
#define RSNGX_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSNGX_SUPPORTED_INSTRUMENT_MODELS        "NGL,NGM,NGP,NGU"    /* Instrument driver supported model(s)     */
#define RSNGX_GROUP_CAPABILITIES                 ""
#define RSNGX_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

 /****************************************************************************
  *---------------------------- Attribute Defines ---------------------------*
  ****************************************************************************/

  /*- Inherent Instrument Specific Attributes ----------------------------*/

      /* User Options */

#define RSNGX_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSNGX_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSNGX_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSNGX_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSNGX_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSNGX_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSNGX_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSNGX_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSNGX_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSNGX_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSNGX_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSNGX_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSNGX_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSNGX_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSNGX_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSNGX_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSNGX_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSNGX_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSNGX_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSNGX_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSNGX_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSNGX_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSNGX_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSNGX_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSNGX_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSNGX_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSNGX_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSNGX_ATTR_SELECT_CHANNEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 391
#define RSNGX_ATTR_RESET_PROTECTION_TRIPPED_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 571
#define RSNGX_ATTR_RESET_VOLTAGE_TRIPPED_STATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 687
#define RSNGX_ATTR_VOLTAGE_TRIPPED_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 688
#define RSNGX_ATTR_SOURCE_PRIORITY_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 677
#define RSNGX_ATTR_MODULATION_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 689
#define RSNGX_ATTR_MODULATION_GAIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 678
#define RSNGX_ATTR_MODULATION_GAIN_VALUE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 679
#define RSNGX_ATTR_NUMBER_OF_POWER_LINE_CYCLES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 680
#define RSNGX_ATTR_VOLTAGE_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSNGX_ATTR_VOLTAGE_LEVEL_UP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSNGX_ATTR_VOLTAGE_LEVEL_DOWN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 395
#define RSNGX_ATTR_VOLTAGE_STEP_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSNGX_ATTR_VOLTAGE_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 690
#define RSNGX_ATTR_VOLTAGE_SAFETY_LIMIT_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSNGX_ATTR_VOLTAGE_SAFETY_LIMIT_LOWER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSNGX_ATTR_VOLTAGE_SAFETY_LIMIT_UPPER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSNGX_ATTR_VOLTAGE_CURRENT_NEGATIVE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 681
#define RSNGX_ATTR_VOLTAGE_CURRENT_NEGATIVE_VALUE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 682
#define RSNGX_ATTR_VOLTAGE_NEGATIVE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 683
#define RSNGX_ATTR_VOLTAGE_NEGATIVE_VALUE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 684
#define RSNGX_ATTR_CURRENT_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 400
#define RSNGX_ATTR_CURRENT_STEP_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSNGX_ATTR_CURRENT_LEVEL_UP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSNGX_ATTR_CURRENT_LEVEL_DOWN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 402
#define RSNGX_ATTR_CURRENT_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 691
#define RSNGX_ATTR_CURRENT_SAFETY_LIMIT_LOWER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSNGX_ATTR_CURRENT_SAFETY_LIMIT_UPPER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSNGX_ATTR_RESISTANCE_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 406
#define RSNGX_ATTR_RESISTANCE_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 407
#define RSNGX_ATTR_OUTPUT_ALL_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 408
#define RSNGX_ATTR_OUTPUT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 409
#define RSNGX_ATTR_OUTPUT_SELECTED_CHANNEL_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSNGX_ATTR_OUTPUT_DELAY_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 411
#define RSNGX_ATTR_OUTPUT_DELAY_DURATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSNGX_ATTR_OUTPUT_FAST_TRANSIENT_RESPONSE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSNGX_ATTR_OUTPUT_REDUCED_SLEW_RATE_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 692
#define RSNGX_ATTR_OUTPUT_IMPEDANCE_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 414
#define RSNGX_ATTR_OUTPUT_IMPEDANCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 415
#define RSNGX_ATTR_OUTPUT_CAPACITANCE_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 693
#define RSNGX_ATTR_OUTPUT_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSNGX_ATTR_OUTPUT_TRIGGER_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSNGX_ATTR_OUTPUT_TRIGGERED_BEHAVIOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 499
#define RSNGX_ATTR_OUTPUT_REMOTE_SENSE_DETECTION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 572
#define RSNGX_ATTR_OUTPUT_QUERY_REMOTE_SENSE_DETECTION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 655
#define RSNGX_ATTR_DVM_MEASUREMENT_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSNGX_ATTR_VOLTAGE_AUTORANGE_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 501
#define RSNGX_ATTR_SELECT_VOLTAGE_RANGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 502
#define RSNGX_ATTR_CURRENT_AUTORANGE_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 503
#define RSNGX_ATTR_CURRENT_AUTORANGE_MINIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 694
#define RSNGX_ATTR_CURRENT_AUTORANGE_OVER_APPROACH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 695
#define RSNGX_ATTR_CURRENT_AUTORANGE_UPPER_THRESHOLD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 696
#define RSNGX_ATTR_CURRENT_AUTORANGE_LOWER_THRESHOLD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 697
#define RSNGX_ATTR_SELECT_CURRENT_RANGE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 504
#define RSNGX_ATTR_OCP_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 505
#define RSNGX_ATTR_OCP_RESET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 506
#define RSNGX_ATTR_OCP_INITIAL_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 507
#define RSNGX_ATTR_OCP_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 508
#define RSNGX_ATTR_OCP_LINK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 509
#define RSNGX_ATTR_OCP_UNLINK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 511
#define RSNGX_ATTR_OCP_TRIPPED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 512
#define RSNGX_ATTR_OCP_FUSE_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 573
#define RSNGX_ATTR_OCP_FUSE_DELAY_TIME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 574
#define RSNGX_ATTR_OCP_FUSE_DELAY_AT_OUTPUT_ON                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 575
#define RSNGX_ATTR_OCP_FUSE_LINK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 576
#define RSNGX_ATTR_OCP_LINKED_FUSES_LIST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 656
#define RSNGX_ATTR_OCP_FUSE_UNLINK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 578
#define RSNGX_ATTR_OCP_FUSE_IS_TRIPPED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 579
#define RSNGX_ATTR_OCP_FUSE_RESET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 580
#define RSNGX_ATTR_OVP_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSNGX_ATTR_OVP_RESET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSNGX_ATTR_OVP_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSNGX_ATTR_OVP_TRIPPED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 426
#define RSNGX_ATTR_OPP_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define RSNGX_ATTR_OPP_RESET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 428
#define RSNGX_ATTR_OPP_LEVEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 429
#define RSNGX_ATTR_OPP_TRIPPED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 430
#define RSNGX_ATTR_TRACKING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 581
#define RSNGX_ATTR_TRACKING_CHANNEL_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 582
#define RSNGX_ATTR_TRACKING_CHANNEL_SOFT_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 583
#define RSNGX_ATTR_MEAS_VOLTAGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 431
#define RSNGX_ATTR_MEAS_VOLTAGE_DVM                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 659
#define RSNGX_ATTR_MEASUREMENT_VOLTAGE_AVG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 561
#define RSNGX_ATTR_MEASUREMENT_VOLTAGE_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 562
#define RSNGX_ATTR_MEASUREMENT_VOLTAGE_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 563
#define RSNGX_ATTR_MEAS_CURRENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 432
#define RSNGX_ATTR_MEASUREMENT_CURRENT_AVG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 564
#define RSNGX_ATTR_MEASUREMENT_CURRENT_MAX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 565
#define RSNGX_ATTR_MEASUREMENT_CURRENT_MIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 566
#define RSNGX_ATTR_MEAS_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 433
#define RSNGX_ATTR_MEASUREMENT_POWER_AVG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 567
#define RSNGX_ATTR_MEASUREMENT_POWER_MAX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 568
#define RSNGX_ATTR_MEASUREMENT_POWER_MIN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 569
#define RSNGX_ATTR_MEAS_ENERGY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 434
#define RSNGX_ATTR_MEASUREMENT_RESET_STATISTICS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 514
#define RSNGX_ATTR_MEASUREMENT_COUNT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 515
#define RSNGX_ATTR_MEAS_LOG_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSNGX_ATTR_MEAS_LOG_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSNGX_ATTR_MEAS_LOG_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 470
#define RSNGX_ATTR_MEAS_LOG_DURATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSNGX_ATTR_MEAS_LOG_INTERVAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSNGX_ATTR_LOG_LOCATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 584
#define RSNGX_ATTR_MEAS_LOG_TRIGGERED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSNGX_ATTR_MEAS_LOG_DELETE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSNGX_ATTR_MEAS_LOG_READ_DATA_CATALOG                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSNGX_ATTR_FAST_LOG_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 516
#define RSNGX_ATTR_FAST_LOG_TRIGGERED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 517
#define RSNGX_ATTR_FAST_LOG_WRITE_TO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 518
#define RSNGX_ATTR_FAST_LOG_SAMPLE_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 519
#define RSNGX_ATTR_FAST_LOG_WRITE_DURATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 521
#define RSNGX_ATTR_FAST_LOG_PARTITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 522
#define RSNGX_ATTR_FAST_LOG_SAMPLE_TIME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 699
#define RSNGX_ATTR_FAST_LOG_EXTERNAL_FILE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 700
#define RSNGX_ATTR_FAST_LOG_EXTERNAL_FILE_DURATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 701
#define RSNGX_ATTR_FAST_LOG_EXTERNAL_FILE_PARTITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 702
#define RSNGX_ATTR_FAST_LOG_TARGET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 662
#define RSNGX_ATTR_MEAS_ENERGY_COUNTER_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 435
#define RSNGX_ATTR_MEAS_ENERGY_COUNTER_RESET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 436
#define RSNGX_ATTR_ENERGY_COUNTER_UNIT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 663
#define RSNGX_ATTR_ARBITRARY_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 437
#define RSNGX_ATTR_ARBITRARY_ENDPOINT_BEHAVIOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSNGX_ATTR_ARBITRARY_CLEAR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSNGX_ATTR_ARBITRARY_PRIORITY_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 703
#define RSNGX_ATTR_ARBITRARY_REPETITION_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSNGX_ATTR_ARBITRARY_TRANSFER_TABLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSNGX_ATTR_ARBITRARY_TRIGGER_INPUT_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSNGX_ATTR_ARBITRARY_TRIGGER_GROUP_CHANNEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 705
#define RSNGX_ATTR_ARBITRARY_TRIGGER_POINT_CHANNEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 706
#define RSNGX_ATTR_ARBITRARY_TRIGGER_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSNGX_ATTR_ARBITRARY_SAVE_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSNGX_ATTR_ARBITRARY_LOAD_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSNGX_ATTR_ARBITRARY_RESTORE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 664
#define RSNGX_ATTR_ARBITRARY_START                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 665
#define RSNGX_ATTR_ARBITRARY_STOP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 666
#define RSNGX_ATTR_ARBITRARY_BLOCK_SELECTED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 585
#define RSNGX_ATTR_ARBITRARY_BLOCK_CLEAR_FILE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 586
#define RSNGX_ATTR_ARBITRARY_BLOCK_REPETITION_RATE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 590
#define RSNGX_ATTR_ARBITRARY_BLOCK_NUMBER_OF_DATA_POINTS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 591
#define RSNGX_ATTR_ARBITRARY_SEQUENCE_CLEAR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 707
#define RSNGX_ATTR_ARBITRARY_SEQUENCE_ENDPOINT_BEHAVIOR                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 592
#define RSNGX_ATTR_ARBITRARY_SEQUENCE_NUMBER_OF_POINTS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 593
#define RSNGX_ATTR_ARBITRARY_SEQUENCE_TRANSFER_TABLE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 594
#define RSNGX_ATTR_ARBITRARY_SEQUENCE_REPETITION_RATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 596
#define RSNGX_ATTR_RAMP_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSNGX_ATTR_RAMP_DURATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSNGX_ATTR_ANALOG_INPUT_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 597
#define RSNGX_ATTR_ANALOG_INPUT_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 598
#define RSNGX_ATTR_ANALOG_INPUT_TRIGGERED_CONDITION_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 599
#define RSNGX_ATTR_ANALOG_INPUT_TRIGGER_PIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 600
#define RSNGX_ATTR_QUERY_ANALOG_INPUT_TRIGGER_PIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 657
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 601
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_DATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 602
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_COUNT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 603
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_START                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 604
#define RSNGX_ATTR_QUERY_ANALOG_IN_ADJUSTMENT_START                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 667
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_VALUE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 606
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_HIGH_VOLTAGE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 607
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_LOW_VOLTAGE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 608
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_END                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 609
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_CANCEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 610
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_SAVE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 611
#define RSNGX_ATTR_ANALOG_IN_ADJUSTMENT_FACTORY_RESTORE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 612
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 613
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_DATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 614
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_COUNT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 615
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_TEMPERATURE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 616
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_START                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 617
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_CURRENT_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 618
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_CURRENT_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 619
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_CURRENT_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 620
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_VOLTAGE_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 621
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_VOLTAGE_MAX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 622
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_VOLTAGE_MIN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 623
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_END                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 624
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_CANCEL                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 625
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_SAVE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 626
#define RSNGX_ATTR_CHANNEL_ADJUSTMENT_FACTORY_RESTORE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 627
#define RSNGX_ATTR_DIGITAL_IO_FAULT_CHANNEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 525
#define RSNGX_ATTR_DIGITAL_IO_FAULT_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 526
#define RSNGX_ATTR_DIGITAL_IO_FAULT_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 527
#define RSNGX_ATTR_DIGITAL_IO_FAULT_SIGNAL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 668
#define RSNGX_ATTR_BATTERY_SIMULATOR_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 530
#define RSNGX_ATTR_BATTERY_SIMULATOR_RESET_MODEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 531
#define RSNGX_ATTR_BATTERY_SIMULATOR_LOAD_MODEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 533
#define RSNGX_ATTR_BATTERY_SIMULATOR_SAVE_MODEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 535
#define RSNGX_ATTR_BATTERY_SIMULATOR_TRANSFER_MODEL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 537
#define RSNGX_ATTR_BATTERY_SIMULATOR_INITIAL_SOC                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 539
#define RSNGX_ATTR_BATTERY_SIMULATOR_FULL_CAPACITY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 540
#define RSNGX_ATTR_BATTERY_SIMULATOR_REMAINING_CAPACITY                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 541
#define RSNGX_ATTR_BATTERY_SIMULATOR_QUERY_STATUS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 542
#define RSNGX_ATTR_BATTERY_SIMULATOR_CURRENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 545
#define RSNGX_ATTR_BATTERY_SIMULATOR_INTERNAL_RESISTANCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 546
#define RSNGX_ATTR_BATTERY_SIMULATOR_STATE_OF_CHARGE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 547
#define RSNGX_ATTR_BATTERY_SIMULATOR_TERMINAL_VOLTAGE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 548
#define RSNGX_ATTR_BATTERY_SIMULATOR_VOC_EMPTY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 549
#define RSNGX_ATTR_BATTERY_SIMULATOR_VOC_FULL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 550
#define RSNGX_ATTR_BATTERY_SIMULATOR_VOC                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 551
#define RSNGX_ATTR_BATTERY_SIMULATOR_MODEL_CAPACITY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 552
#define RSNGX_ATTR_BATTERY_SIMULATOR_CURRENT_LIMIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 553
#define RSNGX_ATTR_BATTERY_SIMULATOR_CURRENT_LIMIT_END_OF_CHARGE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 670
#define RSNGX_ATTR_BATTERY_SIMULATOR_CURRENT_LIMIT_END_OF_DISCHARGE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 671
#define RSNGX_ATTR_BATTERY_SIMULATOR_CURRENT_LIMIT_REGULAR_CHARGE_LEVEL     RS_SPECIFIC_PUBLIC_ATTR_BASE + 672
#define RSNGX_ATTR_BATTERY_MODEL_CURRENT_LIMIT_END_OF_CHARGE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 673
#define RSNGX_ATTR_BATTERY_MODEL_CURRENT_LIMIT_END_OF_DISCHARGE             RS_SPECIFIC_PUBLIC_ATTR_BASE + 674
#define RSNGX_ATTR_BATTERY_MODEL_CURRENT_LIMIT_REGULAR_CHARGE_LEVEL         RS_SPECIFIC_PUBLIC_ATTR_BASE + 675
#define RSNGX_ATTR_DISPLAY_BRIGHTNESS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSNGX_ATTR_DISPLAY_FRONT_PANEL_KEY_BRIGHTNESS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 453
#define RSNGX_ATTR_DISPLAY_CLEAR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSNGX_ATTR_DISPLAY_TEXT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSNGX_ATTR_TRIGGER_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 554
#define RSNGX_ATTR_TRIGGER_SOURCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 555
#define RSNGX_ATTR_TRIGGER_OUTPUT_CHANNEL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 556
#define RSNGX_ATTR_TRIGGER_OPERATION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 557
#define RSNGX_ATTR_TRIGGER_OPERATION_MODE_CHANNEL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 558
#define RSNGX_ATTR_TRIGGER_DIO_PIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 559
#define RSNGX_ATTR_TRIGGER_DIO_CHANNEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 560
#define RSNGX_ATTR_TRIGGER_SLOPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSNGX_ATTR_TRIGGER_SEND_SOFTWARE_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 628
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_LINE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 629
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_LINE_DIRECTION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 630
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_LINE_CHANNEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 632
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_LINE_LOGIC                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 633
#define RSNGX_ATTR_DIGITAL_IO_TRIGGER_LINE_DIO_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 634
#define RSNGX_ATTR_SAVE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSNGX_ATTR_RECALL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSNGX_ATTR_BEEPER_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define RSNGX_ATTR_SOUND_CC_MODE_CONTINUOUS_BEEP_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 635
#define RSNGX_ATTR_SOUND_PROTECTION_TRIPPED_BEEP_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 636
#define RSNGX_ATTR_SOUND_BEEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 637
#define RSNGX_ATTR_SOUND_WARNING_BEEP_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 708
#define RSNGX_ATTR_SOUND_WARNING_BEEP_IMMEDIATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 709
#define RSNGX_ATTR_SOUND_COMPLETE_BEEP_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 710
#define RSNGX_ATTR_SOUND_COMPLETE_BEEP_IMMEDIATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 711
#define RSNGX_ATTR_SOUND_OUTPUT_BEEP_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 712
#define RSNGX_ATTR_IMAGE_WIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSNGX_ATTR_IMAGE_HEIGHT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSNGX_ATTR_SELF_TEST_QUERY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSNGX_ATTR_SYSTEM_ERROR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSNGX_ATTR_ID_QUERY_RESPONSE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSNGX_ATTR_LOGGING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSNGX_ATTR_SYSTEM_SAVE_SETTINGS_FILE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 713
#define RSNGX_ATTR_SYSTEM_RESTART                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 714
#define RSNGX_ATTR_SYSTEM_UPTIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 715
#define RSNGX_ATTR_SYSTEM_LOCAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 483
#define RSNGX_ATTR_SYSTEM_REMOTE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 484
#define RSNGX_ATTR_SYSTEM_RWLOCK                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 485
#define RSNGX_ATTR_SYSTEM_TOUCH_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 638
#define RSNGX_ATTR_GPIB_INTERFACE_INFO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 639
#define RSNGX_ATTR_AVAILABLE_SYSTEM_INTERFACE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 640
#define RSNGX_ATTR_INTERFACE_USB_CLASS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 676
#define RSNGX_ATTR_SOCKET_DHCP_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 641
#define RSNGX_ATTR_SOCKET_IP_ADDRESS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 642
#define RSNGX_ATTR_SOCKET_GATEWAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 643
#define RSNGX_ATTR_SOCKET_MASK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 644
#define RSNGX_ATTR_SOCKET_APPLY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 645
#define RSNGX_ATTR_SOCKET_DISCARD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 716
#define RSNGX_ATTR_SOCKET_RESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 717
#define RSNGX_ATTR_LAN_DHCP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 718
#define RSNGX_ATTR_LAN_IP_ADDRESS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 719
#define RSNGX_ATTR_LAN_MAC_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 720
#define RSNGX_ATTR_LAN_HOSTNAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 721
#define RSNGX_ATTR_LAN_DEFAULT_GATEWAY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 722
#define RSNGX_ATTR_LAN_EDITED_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 723
#define RSNGX_ATTR_LAN_MASK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 724
#define RSNGX_ATTR_LAN_APPLY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 725
#define RSNGX_ATTR_LAN_DISCARD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 726
#define RSNGX_ATTR_LAN_RESET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 727
#define RSNGX_ATTR_WLAN_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 646
#define RSNGX_ATTR_WLAN_CONNECTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 647
#define RSNGX_ATTR_WLAN_SSID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 648
#define RSNGX_ATTR_WLAN_PASSWORD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 649
#define RSNGX_ATTR_WLAN_DHCP_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 650
#define RSNGX_ATTR_WLAN_IP_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 651
#define RSNGX_ATTR_WLAN_GATEWAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 652
#define RSNGX_ATTR_WLAN_MASK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 653
#define RSNGX_ATTR_WLAN_APPLY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 654
#define RSNGX_ATTR_VNC_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 728
#define RSNGX_ATTR_VNC_PORT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 729
#define RSNGX_ATTR_VNC_ENABLED_NGP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 730
#define RSNGX_ATTR_VNC_PORT_NGP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 731

// rsngx_rngRegisterGroup
#define RSNGX_VAL_REGISTER_GROUP_OPER_INSTR                                 0
#define RSNGX_VAL_REGISTER_GROUP_QUES_INSTR                                 1
#define RSNGX_VAL_REGISTER_GROUP_OPER_INSTR_SUMMARY_CHAN_1                  2
#define RSNGX_VAL_REGISTER_GROUP_OPER_INSTR_SUMMARY_CHAN_2                  3
#define RSNGX_VAL_REGISTER_GROUP_QUES_INSTR_SUMMARY_CHAN_1                  4
#define RSNGX_VAL_REGISTER_GROUP_QUES_INSTR_SUMMARY_CHAN_2                  5

// rsngx_rngRegisterType
#define RSNGX_VAL_REGISTER_TYPE_COND                                        0
#define RSNGX_VAL_REGISTER_TYPE_EVEN                                        1
#define RSNGX_VAL_REGISTER_TYPE_ENAB                                        2
#define RSNGX_VAL_REGISTER_TYPE_PTR                                         3
#define RSNGX_VAL_REGISTER_TYPE_NTR                                         4

// RsNgx_rngArbitraryEndpointBehavior
#define RSNGX_VAL_ARB_END_BEHAVIOR_OFF                                      0
#define RSNGX_VAL_ARB_END_BEHAVIOR_HOLD                                     1

// RsNgx_rngTriggerMode
#define RSNGX_VAL_SINGLE                                                    0
#define RSNGX_VAL_RUN                                                       1

// RsNgx_rngLoggingMode
#define RSNGX_VAL_LOGGING_MODE_UNLIMITED                                    0
#define RSNGX_VAL_LOGGING_MODE_COUNT                                        1
#define RSNGX_VAL_LOGGING_MODE_DURATION                                     2
#define RSNGX_VAL_LOGGING_MODE_SPAN                                         3

// RsNgx_rngTriggerSlope
#define RSNGX_VAL_POS                                                       0
#define RSNGX_VAL_NEG                                                       1

// RsNgx_rngLocation
#define RSNGX_VAL_LOCATION_INT                                              0
#define RSNGX_VAL_LOCATION_EXT                                              1
#define RSNGX_VAL_LOCATION_DEF                                              2

// RsNgx_rngMeasurementType
#define RSNGX_VAL_MEASURE_VOLTAGE                                           0
#define RSNGX_VAL_MEASURE_CURRENT                                           1
#define RSNGX_VAL_MEASURE_POWER                                             2
#define RSNGX_VAL_MEASURE_ENERGY                                            3

// RsNgx_rngOutputTriggeredBehavior
#define RSNGX_VAL_OUTPUT_TRIGGERED_BEHAVIOR_ON                              0
#define RSNGX_VAL_OUTPUT_TRIGGERED_BEHAVIOR_OFF                             1
#define RSNGX_VAL_OUTPUT_TRIGGERED_BEHAVIOR_GATED                           2

// RsNgx_rngSelectVoltageRange
#define RSNGX_VAL_VOLTAGE_RANGE_TWENTY                                      0
#define RSNGX_VAL_VOLTAGE_RANGE_FIVE                                        1

// RsNgx_rngSelectCurrentRange
#define RSNGX_VAL_CURRENT_RANGE_10A                                         0
#define RSNGX_VAL_CURRENT_RANGE_1A                                          1
#define RSNGX_VAL_CURRENT_RANGE_100mA                                       2
#define RSNGX_VAL_CURRENT_RANGE_10mA                                        3

// RsNgx_rngTriggerSource
#define RSNGX_VAL_TRIGGER_SOURCE_OUTPUT                                     0
#define RSNGX_VAL_TRIGGER_SOURCE_OPERATION_MODES                            1
#define RSNGX_VAL_TRIGGER_SOURCE_DIO                                        2

// RsNgx_rngTriggerDIOPin
#define RSNGX_VAL_TRIGGER_DIO_PIN_IN                                        0
#define RSNGX_VAL_TRIGGER_DIO_PIN_EXT                                       1

// RsNgx_rngTriggerOperationMode
#define RSNGX_TRIGGER_OPERATION_MODE_CC                                     0
#define RSNGX_TRIGGER_OPERATION_MODE_CV                                     1
#define RSNGX_TRIGGER_OPERATION_MODE_CR                                     2
#define RSNGX_TRIGGER_OPERATION_MODE_SINK                                   3
#define RSNGX_TRIGGER_OPERATION_MODE_PROTECTION                             4

// RsNgx_rngOutputChannel
#define RSNGX_VAL_CHANNEL_OUT1                                              1
#define RSNGX_VAL_CHANNEL_OUT2                                              2
#define RSNGX_VAL_CHANNEL_ANY                                               3

// RsNgx_rngDigitalIOFaultMode
#define RSNGX_DIGITAL_IO_OPERATION_MODE_CC                                  0
#define RSNGX_DIGITAL_IO_OPERATION_MODE_CV                                  1
#define RSNGX_DIGITAL_IO_OPERATION_MODE_CR                                  2
#define RSNGX_DIGITAL_IO_OPERATION_MODE_SINK                                3
#define RSNGX_DIGITAL_IO_OPERATION_MODE_PROTECTION                          4
#define RSNGX_DIGITAL_IO_OPERATION_MODE_OUTPUT                              5

// RsNgx_rngFastLogSampleRate
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_500K                                 0
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_250K                                 1
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_50K                                  2
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_10K                                  3
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_1K                                   4
#define RSNGX_VAL_FAST_LOG_SAMPLE_RATE_100                                  5

// RsNgx_rngOutputMode
#define RSNGX_VAL_OUTPUT_MODE_AUTO                                          0
#define RSNGX_VAL_OUTPUT_MODE_SINK                                          1
#define RSNGX_VAL_OUTPUT_MODE_SOURCE                                        2

// RsNgx_rngMeasurementStatisticsType
#define RSNGX_VAL_AVG                                                       0
#define RSNGX_VAL_MIN                                                       1
#define RSNGX_VAL_MAX                                                       2

// RsNgx_rngDigitalIOOutputSource
#define RSNGX_VAL_DIGITAL_IO_OUTPUT_SOURCE_OUTPUT                           0
#define RSNGX_VAL_DIGITAL_IO_OUTPUT_SOURCE_TRIGGERED                        1
#define RSNGX_VAL_DIGITAL_IO_OUTPUT_SOURCE_FORCED                           2

// RsNgx_rngFastLogWriteTo
#define RSNGX_VAL_FAST_LOG_WRITE_TO_SCPI                                    0
#define RSNGX_VAL_FAST_LOG_WRITE_TO_USB                                     1

// RsNgx_rngBatterySimulatorModelNamePartition
#define RSNGX_VAL_BATTERY_MODEL_NAME_PARTITION_INT                          0
#define RSNGX_VAL_BATTERY_MODEL_NAME_PARTITION_EXT                          1
#define RSNGX_VAL_BATTERY_MODEL_NAME_PARTITION_DEF                          2

// RsNgx_rngBatterySimulatorStatus
#define RSNGX_VAL_BATTERY_SIMULATOR_STATUS_IDLE                             0
#define RSNGX_VAL_BATTERY_SIMULATOR_STATUS_CHAR                             1
#define RSNGX_VAL_BATTERY_SIMULATOR_STATUS_DISC                             2

// RsNgx_rngAnalogInputType
#define RSNGX_VAL_INPUT_VOLT                                                0
#define RSNGX_VAL_INPUT_CURR                                                1

// RsNgx_rngEnabled
#define RSNGX_VAL_DISABLED                                                  0
#define RSNGX_VAL_ENABLED                                                   1

// RsNgx_rngRemoteSenseDetection
#define RSNGX_VAL_REMOTE_SENSE_AUTO                                         0
#define RSNGX_VAL_REMOTE_SENSE_EXT                                          1
#define RSNGX_VAL_REMOTE_SENSE_INT                                          2

// RsNgx_rngDigitalTriggerIOLineMode
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_OUTPUT                               0
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_OVP                                  1
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_FUSE                                 2
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_OTP                                  3
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_OPP                                  4
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_VMODE                                5
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_CMODE                                6
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_VLEVEL                               7
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ILEVEL                               8
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ENABLE                               9
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_INHIBIT                              10
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ARB                                  11
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_RAMP                                 12
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ANINPUT                              13
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_STATISTICS                           14
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_LOGGING                              15
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_PLEVEL                               16
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ARB_POINT                            17
#define RSNGX_VAL_DIGITAL_TRIGGER_MODE_ARB_GROUP                            18

// RsNgx_rngDigitalIOTriggerDirection
#define RSNGX_VAL_LINE_DIR_OUTPUT                                           0
#define RSNGX_VAL_LINE_DIR_INPUT                                            1

// RsNgx_rngDigitalIOTriggerLineChannel
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_ALL                                  0
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_CH1                                  1
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_CH2                                  2
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_CH3                                  3
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_CH4                                  4
#define RSNGX_VAL_TRIGGER_LINE_CHANNEL_NONE                                 5

// RsNgx_rngDigitalIOTriggerLineLogic
#define RSNGX_VAL_DIGITAL_TRIGGER_LINE_LOGIC_LOW                            0
#define RSNGX_VAL_DIGITAL_TRIGGER_LINE_LOGIC_HIGH                           1

// RsNgx_rngRemoteSenseDetectionResponse
#define RSNGX_VAL_REMOTE_SENSE_RESPONSE_AUTO_OFF                            0
#define RSNGX_VAL_REMOTE_SENSE_RESPONSE_AUTO_ON                             1
#define RSNGX_VAL_REMOTE_SENSE_RESPONSE_EXT                                 2
#define RSNGX_VAL_REMOTE_SENSE_RESPONSE_INT                                 3

// RsNgx_rngAnalogInputPinResponse
#define RSNGX_VAL_ANALOG_INPUT_PIN_RESPONSE_OUT1                            1
#define RSNGX_VAL_ANALOG_INPUT_PIN_RESPONSE_OUT2                            2
#define RSNGX_VAL_ANALOG_INPUT_PIN_RESPONSE_OUT3                            3
#define RSNGX_VAL_ANALOG_INPUT_PIN_RESPONSE_OUT4                            4

// RsNgx_rngDigitalIOFaultSignal
#define RSNGX_VAL_DIO_FAULT_SIGNAL_CONS                                     0
#define RSNGX_VAL_DIO_FAULT_SIGNAL_PULS                                     1

// RsNgx_rngFastLogTarget
#define RSNGX_VAL_FAST_LOG_TARGET_SCPI                                      0
#define RSNGX_VAL_FAST_LOG_TARGET_USB                                       1

// RsNgx_rngEnergyCounterUnit
#define RSNGX_VAL_ENERGY_COUNTER_UNIT_WS                                    0
#define RSNGX_VAL_ENERGY_COUNTER_UNIT_WH                                    1

// RsNgx_rngInterfaceUSBClass
#define RSNGX_VAL_INTERFACE_USB_CLASS_CDC                                   0
#define RSNGX_VAL_INTERFACE_USB_CLASS_TMC                                   1

// RsNgx_rngSourcePriorityMode
#define RSNGX_VAL_SOURCE_PRIORITY_MODE_VOLT                                 0
#define RSNGX_VAL_SOURCE_PRIORITY_MODE_CURR                                 1

// RsNgx_rngVoltageCurrentNegative
#define RSNGX_VAL_VOLTAGE_CURRENT_NEGATIVE_MIN                              1
#define RSNGX_VAL_VOLTAGE_CURRENT_NEGATIVE_MAX                              2
#define RSNGX_VAL_VOLTAGE_CURRENT_NEGATIVE_UP                               3
#define RSNGX_VAL_VOLTAGE_CURRENT_NEGATIVE_DOWN                             4

// RsNgx_rngArbitraryTriggerDIOPin
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_OFF                             0
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_1                               1
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_2                               2
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_3                               3
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_4                               4
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_5                               5
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_6                               6
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_7                               7
#define RSNGX_VAL_ARBITRARY_TRIGGER_DIO_PIN_8                               8

// RsNgx_rngArbitraryPriorityMode
#define RSNGX_VAL_ARBITRARY_PRIORITY_MODE_CPM                               0
#define RSNGX_VAL_ARBITRARY_PRIORITY_MODE_VPM                               1

// RsNgx_rngCurrentAutoRangeOverApproach
#define RSNGX_VAL_CURRENT_AUTO_RANGE_OVER_APPROACH_DEFAULT                  0
#define RSNGX_VAL_CURRENT_AUTO_RANGE_OVER_APPROACH_TOP                      1
#define RSNGX_VAL_CURRENT_AUTO_RANGE_OVER_APPROACH_STEP                     2

// RsNgx_rngOutputCapacitanceMode
#define RSNGX_VAL_OUTPUT_CAPACITANCE_MODE_OFF                               0
#define RSNGX_VAL_OUTPUT_CAPACITANCE_MODE_LOW                               1
#define RSNGX_VAL_OUTPUT_CAPACITANCE_MODE_HIGH                              2

//repcap Channel
#define RSNGX_REPCAP_CHANNEL_CH1                                            1
#define RSNGX_REPCAP_CHANNEL_CH2                                            2
#define RSNGX_REPCAP_CHANNEL_CH3                                            3
#define RSNGX_REPCAP_CHANNEL_CH4                                            4

//repcap Line
#define RSNGX_REPCAP_LINE_L1                                                1
#define RSNGX_REPCAP_LINE_L2                                                2
#define RSNGX_REPCAP_LINE_L3                                                3
#define RSNGX_REPCAP_LINE_L4                                                4
#define RSNGX_REPCAP_LINE_L5                                                5
#define RSNGX_REPCAP_LINE_L6                                                6
#define RSNGX_REPCAP_LINE_L7                                                7
#define RSNGX_REPCAP_LINE_L8                                                8
/* END GENERATE */
/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSNGX_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSNGX_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSNGX_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSNGX_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

 /****************************************************************************
  *---------------- Constant definition  ------------------------------------*
  ****************************************************************************/

#define RSNGX_VAL_FUSE_LINKING   0
#define RSNGX_VAL_FUSE_UNLINKING 1

#define RSNGX_VAL_FILE_OPER_SAVE 0
#define RSNGX_VAL_FILE_OPER_LOAD 1

#define RSNGX_VAL_SAVE   0
#define RSNGX_VAL_RECALL 1

#define RSNGX_VAL_LOAD 1

#define RSNGX_VAL_ARB_CONTROL_RESTORE 0
#define RSNGX_VAL_ARB_CONTROL_START   1
#define RSNGX_VAL_ARB_CONTROL_STOP    2

#define RSNGX_VAL_VOLTAGE_CURRENT_NEGATIVE_VAL 0

  /****************************************************************************
   *---------------- Instrument Driver Function Declarations -----------------*
   ****************************************************************************/
ViStatus _VI_FUNC rsngx_init(ViRsrc     resourceName,
                             ViBoolean  IDQuery,
                             ViBoolean  resetDevice,
                             ViSession* instrSession);

ViStatus _VI_FUNC rsngx_InitWithOptions(ViRsrc     resourceName,
                                        ViBoolean  IDQuery,
                                        ViBoolean  resetDevice,
                                        ViString   optionString,
                                        ViSession* instrSession);

ViStatus _VI_FUNC rsngx_ConfigureOutput(ViSession instrSession,
                                        ViInt32   channel,
                                        ViReal64  voltage,
                                        ViReal64  current);

ViStatus _VI_FUNC rsngx_ReadVoltageCurrentPair(ViSession instrSession,
                                               ViInt32   channel,
                                               ViReal64* voltage,
                                               ViReal64* current);

ViStatus _VI_FUNC rsngx_ConfigureVoltageLevel(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  voltageLevel);

ViStatus _VI_FUNC rsngx_ConfigureVoltageRange(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  range);

ViStatus _VI_FUNC rsngx_ConfigureVoltageSafetyLimit(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViBoolean safetyLimitState,
                                                    ViReal64  lowerSafetyLimit,
                                                    ViReal64  upperSafetyLimit);

ViStatus _VI_FUNC rsngx_ConfigureVoltageCurrentNegative(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   voltage,
                                                        ViReal64  voltageValue);

ViStatus _VI_FUNC rsngx_ConfigureVoltageNegative(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   voltage,
                                                 ViReal64  voltageValue);

ViStatus _VI_FUNC rsngx_QueryMaxVoltageLevel(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  currentLevel,
                                             ViReal64* maxVoltageLevel);

ViStatus _VI_FUNC rsngx_ConfigureCurrentLevel(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  currentLevel);

ViStatus _VI_FUNC rsngx_ConfigureCurrentRange(ViSession instrSession,
                                              ViInt32   channel,
                                              ViReal64  range);

ViStatus _VI_FUNC rsngx_ConfigureCurrentSafetyLimit(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViReal64  lowerSafetyLimit,
                                                    ViReal64  upperSafetyLimit);

ViStatus _VI_FUNC rsngx_QueryMaxCurrentLevel(ViSession instrSession,
                                             ViInt32   channel,
                                             ViReal64  voltageLevel,
                                             ViReal64* maxCurrentLevel);

ViStatus _VI_FUNC rsngx_ConfigureResistance(ViSession instrSession,
                                            ViInt32   channel,
                                            ViBoolean enabled,
                                            ViReal64  level);

ViStatus _VI_FUNC rsngx_ConfigureOutputEnabled(ViSession instrSession,
                                               ViInt32   channel,
                                               ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureOutputSelectedChannelEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureOutputAllEnabled(ViSession instrSession,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureOutputDelay(ViSession instrSession,
                                             ViInt32   channel,
                                             ViBoolean enabled,
                                             ViReal64  duration);

ViStatus _VI_FUNC rsngx_ConfigureOutputFastTransientResponseEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureOutputReducedSlewRateEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean reducedSlewRate);

ViStatus _VI_FUNC rsngx_ConfigureOutputImpedance(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViBoolean enabled,
                                                 ViReal64  impedance);

ViStatus _VI_FUNC rsngx_ConfigureOutputMode(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   outputMode);

ViStatus _VI_FUNC rsngx_ConfigureOutputTriggerSettings(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViBoolean triggerEnabled,
                                                       ViInt32   triggeredBehavior);

ViStatus _VI_FUNC rsngx_ConfigureOutputRemoteSenseDetection(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   remoteSenseDetection);

ViStatus _VI_FUNC rsngx_QueryOutputRemoteSenseDetection(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32*  remoteSenseDetection);

ViStatus _VI_FUNC rsngx_ConfigureOutputCapacitanceMode(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   capacitanceMode);

ViStatus _VI_FUNC rsngx_ConfigureDVMMeasurementSettings(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViBoolean enableDVM,
                                                        ViBoolean enableVoltageAutorange,
                                                        ViInt32   selectVoltageRange,
                                                        ViBoolean enableCurrentAutorange,
                                                        ViInt32   selectCurrentRange);

ViStatus _VI_FUNC rsngx_ConfigureCurrentAutorangeMinimum(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViReal64  autorangeMinimum);

ViStatus _VI_FUNC rsngx_ConfigureCurrentAutorangeOverApproach(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   approach);

ViStatus _VI_FUNC rsngx_ConfigureCurrentAutorangeThresholds(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViReal64  upperThreshold,
                                                            ViReal64  lowerThreshold);

ViStatus _VI_FUNC rsngx_ConfigureOCP(ViSession instrSession,
                                     ViInt32   channel,
                                     ViBoolean enabled,
                                     ViReal64  delay);

ViStatus _VI_FUNC rsngx_ConfigureOCPInitialDelay(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViReal64  initialDelay);

ViStatus _VI_FUNC rsngx_ConfigureOCPLinking(ViSession instrSession,
                                            ViInt32   channel,
                                            ViInt32   OCPLinkingType,
                                            ViInt32   OCPLink);

ViStatus _VI_FUNC rsngx_QueryOCPLinking(ViSession  instrSession,
                                        ViInt32    channel,
                                        ViInt32    linkedChannel,
                                        ViBoolean* linkState);

ViStatus _VI_FUNC rsngx_QueryOCPTripped(ViSession  instrSession,
                                        ViInt32    channel,
                                        ViBoolean* OCPTripped);

ViStatus _VI_FUNC rsngx_ResetOCP(ViSession instrSession,
                                 ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureOCPFuse(ViSession instrSession,
                                         ViInt32   channel,
                                         ViInt32   enabled,
                                         ViReal64  delayTime);

ViStatus _VI_FUNC rsngx_ConfigureOCPFuseInitialDelay(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViReal64  initialDelay);

ViStatus _VI_FUNC rsngx_ConfigureOCPFuseLinking(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   fuseLinkingType,
                                                ViInt32   fuseLink);

ViStatus _VI_FUNC rsngx_QueryOCPLinkedFusesList(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   bufferSize,
                                                ViChar    linkedFusesList[]);

ViStatus _VI_FUNC rsngx_QueryOCPFuseTripped(ViSession  instrSession,
                                            ViInt32    channel,
                                            ViBoolean* OCPTripped);

ViStatus _VI_FUNC rsngx_ResetOCPFuse(ViSession instrSession,
                                     ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureOVP(ViSession instrSession,
                                     ViInt32   channel,
                                     ViBoolean enabled,
                                     ViReal64  level);

ViStatus _VI_FUNC rsngx_ResetOVP(ViSession instrSession,
                                 ViInt32   channel);

ViStatus _VI_FUNC rsngx_QueryOVPTripped(ViSession  instrSession,
                                        ViInt32    channel,
                                        ViBoolean* tripped);

ViStatus _VI_FUNC rsngx_ConfigureOPP(ViSession instrSession,
                                     ViInt32   channel,
                                     ViBoolean enabled,
                                     ViReal64  level);

ViStatus _VI_FUNC rsngx_ResetOPP(ViSession instrSession,
                                 ViInt32   channel);

ViStatus _VI_FUNC rsngx_QueryOPPTripped(ViSession  instrSession,
                                        ViInt32    channel,
                                        ViBoolean* tripped);

ViStatus _VI_FUNC rsngx_ResetProtectionTrippedState(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ResetVoltageTrippedState(ViSession instrSession,
                                                 ViInt32   channel);

ViStatus _VI_FUNC rsngx_QueryVoltageTrippedState(ViSession  instrSession,
                                                 ViInt32    channel,
                                                 ViBoolean* trippedState);

ViStatus _VI_FUNC rsngx_ConfigureRamp(ViSession instrSession,
                                      ViInt32   channel,
                                      ViBoolean enabled,
                                      ViReal64  duration);

ViStatus _VI_FUNC rsngx_ConfigureSourcePriorityMode(ViSession instrSession,
                                                    ViInt32   priorityMode);

ViStatus _VI_FUNC rsngx_ConfigureNumberOfPowerLineCycles(ViSession instrSession,
                                                         ViInt32   powerLineCycles);

ViStatus _VI_FUNC rsngx_ConfigureModulationEnabled(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViBoolean modulation);

ViStatus _VI_FUNC rsngx_ConfigureModulationGain(ViSession instrSession,
                                                ViInt32   gain,
                                                ViReal64  gainValue);

ViStatus _VI_FUNC rsngx_ConfigureTrackingEnabled(ViSession instrSession,
                                                 ViInt32   trackingEnabled);

ViStatus _VI_FUNC rsngx_ConfigureTrackingChannelEnabled(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   trackingEnabled);

ViStatus _VI_FUNC rsngx_ConfigureTrackingChannelSoftEnabled(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViInt32   trackingSoftEnabled);

ViStatus _VI_FUNC rsngx_QueryMeasurementData(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   measurementType,
                                             ViReal64* data);

ViStatus _VI_FUNC rsngx_QueryMeasurementDataDVM(ViSession instrSession,
                                                ViReal64* data);

ViStatus _VI_FUNC rsngx_ConfigureEnergyCounterEnabled(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ResetEnergyCounter(ViSession instrSession,
                                           ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureEnergyCounterUnit(ViSession instrSession,
                                                   ViInt32   unit);

ViStatus _VI_FUNC rsngx_QueryMeasurementStatisticsData(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   measurementType,
                                                       ViInt32   statisticsType,
                                                       ViReal64* statisticsData);

ViStatus _VI_FUNC rsngx_QueryMeasurementStatisticsDataAll(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViInt32   measurementType,
                                                          ViInt32   arraySize,
                                                          ViReal64  statisticsData[]);

ViStatus _VI_FUNC rsngx_ResetMeasurementStatistics(ViSession instrSession,
                                                   ViInt32   channel);

ViStatus _VI_FUNC rsngx_QueryMeasurementCount(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32*  measurementCount);

ViStatus _VI_FUNC rsngx_ConfigureLogging(ViSession instrSession,
                                         ViBoolean enabled,
                                         ViInt32   mode,
                                         ViInt32   count,
                                         ViReal64  duration,
                                         ViReal64  interval);

ViStatus _VI_FUNC rsngx_ConfigureLoggingStartTime(ViSession instrSession,
                                                  ViInt32   year,
                                                  ViInt32   month,
                                                  ViInt32   day,
                                                  ViInt32   hour,
                                                  ViInt32   minute,
                                                  ViInt32   second);

ViStatus _VI_FUNC rsngx_ConfigureLoggingTriggered(ViSession instrSession,
                                                  ViBoolean triggered);

ViStatus _VI_FUNC rsngx_ConfigureLogLocation(ViSession instrSession,
                                             ViInt32   location);

ViStatus _VI_FUNC rsngx_ReadLogData(ViSession instrSession,
                                    ViInt32   channel,
                                    ViInt32   arraySize,
                                    ViReal64  logData[],
                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_ConfigureLoggingFile(ViSession instrSession,
                                             ViString  filename,
                                             ViInt32   location);

ViStatus _VI_FUNC rsngx_ReadFileFromInstrument(ViSession instrSession,
                                               ViString  filename,
                                               ViInt32   bufferSize,
                                               ViChar    fileContent[],
                                               ViInt32*  responseLength);

ViStatus _VI_FUNC rsngx_DeleteFile(ViSession instrSession,
                                   ViString  fileToDelete);

ViStatus _VI_FUNC rsngx_ReadDataPoints(ViSession instrSession,
                                       ViString  filename,
                                       ViUInt32* points);

ViStatus _VI_FUNC rsngx_ReadDataCatalog(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViChar    catalog[]);

ViStatus _VI_FUNC rsngx_ConfigureFastLogEnabled(ViSession instrSession,
                                                ViInt32   channel,
                                                ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureFastLogSettings(ViSession instrSession,
                                                 ViInt32   channel,
                                                 ViInt32   writeTo,
                                                 ViReal64  writeDuration,
                                                 ViInt32   sampleRate);

ViStatus _VI_FUNC rsngx_ConfigureFastLogTriggered(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViBoolean triggered);

ViStatus _VI_FUNC rsngx_ReadFastLogDataFromInstrument(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32*  responseLength,
                                                      ViInt32   bufferSize,
                                                      ViChar    fileContent[]);

ViStatus _VI_FUNC rsngx_ConfigureFastLogPartition(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViString  fastLogPartition);

ViStatus _VI_FUNC rsngx_ConfigureFastLogSampleTime(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViReal64  sampleTime);

ViStatus _VI_FUNC rsngx_ConfigureFastLogExternalFileSettings(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViBoolean externalFile,
                                                             ViReal64  duration,
                                                             ViString  partition);

ViStatus _VI_FUNC rsngx_ConfigureFastLogTarget(ViSession instrSession,
                                               ViInt32   target);

ViStatus _VI_FUNC rsngx_ConfigureArbitrary(ViSession instrSession,
                                           ViInt32   channel,
                                           ViBoolean enabled,
                                           ViInt32   repetitionRate,
                                           ViInt32   endpoint,
                                           ViInt32   endpointBehavior);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryFile(ViSession instrSession,
                                               ViInt32   channel,
                                               ViString  filename,
                                               ViInt32   location,
                                               ViInt32   operation);

ViStatus _VI_FUNC rsngx_ResetArbitrary(ViSession instrSession,
                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_TransferArbitraryTable(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   transferTableToChannel);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryTriggerInputEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryTriggerGroupChannel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   groupChannel);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryTriggerPointChannel(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   pointChannel);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryTriggerMode(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViInt32   arbitraryTriggerMode);

ViStatus _VI_FUNC rsngx_WriteArbitraryData(ViSession instrSession,
                                           ViInt32   channel,
                                           ViInt32   numberOfValues,
                                           ViReal64  voltage[],
                                           ViReal64  current[],
                                           ViReal64  time[],
                                           ViInt32   interpolationMode[]);

ViStatus _VI_FUNC rsngx_ReadArbitraryData(ViSession instrSession,
                                          ViInt32   channel,
                                          ViInt32   arraySize,
                                          ViReal64  voltage[],
                                          ViReal64  current[],
                                          ViReal64  time[],
                                          ViInt32   interpolationMode[],
                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryPriorityMode(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   arbitraryPriorityMode);

ViStatus _VI_FUNC rsngx_ReadArbitraryCPMData(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   arraySize,
                                             ViReal64  CPMData[],
                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_WriteArbitraryCPMData(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   numberOfValues,
                                              ViReal64  positiveVoltage[],
                                              ViReal64  negativeVoltage[],
                                              ViReal64  current[],
                                              ViReal64  time[],
                                              ViInt32   interpolationMode[]);

ViStatus _VI_FUNC rsngx_ReadArbitraryVPMData(ViSession instrSession,
                                             ViInt32   channel,
                                             ViInt32   arraySize,
                                             ViReal64  VPMData[],
                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_WriteArbitraryVPMData(ViSession instrSession,
                                              ViInt32   channel,
                                              ViInt32   numberOfValues,
                                              ViReal64  voltage[],
                                              ViReal64  positiveCurrent[],
                                              ViReal64  negativeCurrent[],
                                              ViReal64  time[],
                                              ViInt32   interpolationMode[]);

ViStatus _VI_FUNC rsngx_ClearArbitrarySequence(ViSession instrSession,
                                               ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryControl(ViSession instrSession,
                                                  ViInt32   control);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryBlockRepetitionRate(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   block,
                            ViInt32   repetitionRate);

ViStatus _VI_FUNC rsngx_QueryArbitraryBlockNumberOfDataPoints(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViInt32   block,
                            ViInt32*  numberOfDataPoints);

ViStatus _VI_FUNC rsngx_ConfigureArbitraryBlockFileName(ViSession instrSession,
                                                        ViInt32   channel,
                                                        ViInt32   block,
                                                        ViString  fileName,
                                                        ViInt32   location);

ViStatus _VI_FUNC rsngx_ClearArbitraryBlockFile(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   block);

ViStatus _VI_FUNC rsngx_WriteBlockArbitraryData(ViSession instrSession,
                                                ViInt32   channel,
                                                ViInt32   block,
                                                ViInt32   numberOfValues,
                                                ViReal64  voltage[],
                                                ViReal64  current[],
                                                ViReal64  time[],
                                                ViInt32   interpolationMode[]);

ViStatus _VI_FUNC rsngx_ReadBlockArbitraryData(ViSession instrSession,
                                               ViInt32   channel,
                                               ViInt32   block,
                                               ViInt32   arraySize,
                                               ViReal64  voltage[],
                                               ViReal64  current[],
                                               ViReal64  time[],
                                               ViInt32   interpolationMode[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_ConfigureArbitrarySequenceSettings(ViSession instrSession,
                                                           ViInt32   repetitionRate,
                                                           ViInt32   channel,
                                                           ViInt32   endpointBehavior);

ViStatus _VI_FUNC rsngx_QueryArbitrarySequenceNumberOfPoints(ViSession instrSession,
                                                             ViInt32   channel,
                                                             ViInt32*  numberOfPoints);

ViStatus _VI_FUNC rsngx_TransferArbitrarySequenceTable(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureAnalogInputSettings(ViSession instrSession,
                                                     ViInt32   channel,
                                                     ViInt32   enabled,
                                                     ViInt32   type);

ViStatus _VI_FUNC rsngx_ConfigureAnalogInputTriggeredConditionEnabled(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsngx_ConfigureAnalogInputTriggerPin(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   pin);

ViStatus _VI_FUNC rsngx_QueryAnalogInputTriggerPin(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32   bufferSize,
                                                   ViChar    pin[]);

ViStatus _VI_FUNC rsngx_QueryAnalogInAdjustmentState(ViSession instrSession,
                                                     ViInt32*  adjustmentState);

ViStatus _VI_FUNC rsngx_RestoreAnalogInFactoryAdjustment(ViSession instrSession);

ViStatus _VI_FUNC rsngx_QueryAnalogInPreviousAdjustmentsInformation(
                            ViSession instrSession,
                            ViChar    lastAdjustmentDate[],
                            ViInt32*  timesAdjusted);

ViStatus _VI_FUNC rsngx_ConfigureAnalogInAdjustmentPin(ViSession instrSession,
                                                       ViInt32   pin);

ViStatus _VI_FUNC rsngx_QueryAnalogInAdjustmentPin(ViSession instrSession,
                                                   ViInt32*  pin);

ViStatus _VI_FUNC rsngx_ConfigureAnalogInAdjustmentValue(ViSession instrSession,
                                                         ViReal64  adjustmentValue);

ViStatus _VI_FUNC rsngx_SetAnalogInAdjustmentHighVoltage(ViSession instrSession);

ViStatus _VI_FUNC rsngx_SetAnalogInAdjustmentLowVoltage(ViSession instrSession);

ViStatus _VI_FUNC rsngx_SaveAnalogInAdjustment(ViSession instrSession);

ViStatus _VI_FUNC rsngx_EndAnalogInAdjustment(ViSession instrSession);

ViStatus _VI_FUNC rsngx_CancelAnalogInAdjustment(ViSession instrSession);

ViStatus _VI_FUNC rsngx_QueryChannelAdjustmentState(ViSession instrSession,
                                                    ViInt32   channel,
                                                    ViInt32*  adjustmentState);

ViStatus _VI_FUNC rsngx_QueryChannelPreviousAdjustmentInformation(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViChar    lastAdjustmentDate[],
                            ViInt32*  timesAdjusted);

ViStatus _VI_FUNC rsngx_QueryChannelAdjustmentTemperature(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64* temperature);

ViStatus _VI_FUNC rsngx_ConfigureChannelAdjustmentStart(ViSession instrSession,
                                                        ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureChannelAdjustmentCurrentValue(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  currentValue);

ViStatus _VI_FUNC rsngx_SetChannelAdjustmentCurrentMin(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_SetChannelAdjustmentCurrentMax(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureChannelAdjustmentVoltageValue(
                            ViSession instrSession,
                            ViInt32   channel,
                            ViReal64  voltageValue);

ViStatus _VI_FUNC rsngx_SetChannelAdjustmentVoltageMax(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_SetChannelAdjustmentVoltageMin(ViSession instrSession,
                                                       ViInt32   channel);

ViStatus _VI_FUNC rsngx_SaveChannelAdjustment(ViSession instrSession,
                                              ViInt32   channel);

ViStatus _VI_FUNC rsngx_EndChannelAdjustment(ViSession instrSession,
                                             ViInt32   channel);

ViStatus _VI_FUNC rsngx_CancelChannelAdjustment(ViSession instrSession,
                                                ViInt32   channel);

ViStatus _VI_FUNC rsngx_RestoreChannelFactoryAdjustment(ViSession instrSession,
                                                        ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOEnabled(ViSession instrSession,
                                                  ViInt32   channel,
                                                  ViBoolean digitalIOEnabled);

ViStatus _VI_FUNC rsngx_QueryDigitalIOState(ViSession  instrSession,
                                            ViInt32    channel,
                                            ViBoolean* digitalIOState);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOFaultChannel(ViSession instrSession,
                                                       ViInt32   faultChannel);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOFault(ViSession instrSession,
                                                ViBoolean faultEnabled,
                                                ViInt32   sourceMode);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOFaultSignal(ViSession instrSession,
                                                      ViInt32   signal);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOOutputSource(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   outputSource);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOOutputSignal(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsngx_QueryDigitalIOOutputSource(ViSession instrSession,
                                                   ViInt32   channel,
                                                   ViInt32*  digitalOutputSource);

ViStatus _VI_FUNC rsngx_ConfigureBatterySimulatorEnabled(ViSession instrSession,
                                                         ViInt32   channel,
                                                         ViBoolean batterySimulatorEnabled);

ViStatus _VI_FUNC rsngx_ResetBatterySimulatorModel(ViSession instrSession,
                                                   ViInt32   channel);

ViStatus _VI_FUNC rsngx_ManageBatterySimulatorModelSettings(ViSession instrSession,
                                                            ViInt32   action);

ViStatus _VI_FUNC rsngx_ConfigureBatterySimulatorModelStats(ViSession instrSession,
                                                            ViInt32   channel,
                                                            ViString  modelName,
                                                            ViInt32   modelPartition,
                                                            ViReal64  capacity,
                                                            ViReal64  initialStateOfCharge);

ViStatus _VI_FUNC rsngx_ConfigureBatterySimulatorModelData(ViSession instrSession,
                                                           ViInt32   stateOfCharge_SoC[],
                                                           ViReal64  opencircuitVoltage_VoC[],
                                                           ViReal64  internalResistance_ESR[],
                                                           ViInt32   numberOfValues);

ViStatus _VI_FUNC rsngx_QueryBatterySimulatorModelData(ViSession instrSession,
                                                       ViInt32   arraySize,
                                                       ViInt32   stateOfCharge_SoC[],
                                                       ViReal64  opencircuitVoltage_VoC[],
                                                       ViReal64  internalResistance_ESR[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_TransferBatterySimulatorModel(ViSession instrSession,
                                                      ViInt32   transferToChannel);

ViStatus _VI_FUNC rsngx_ConfigureBatterySimulatorSettings(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64  fullCapacity,
                                                          ViReal64  stateOfCharge);

ViStatus _VI_FUNC rsngx_QueryBatterySimulatorCurrentLimit(ViSession instrSession,
                                                          ViInt32   channel,
                                                          ViReal64* currentLimit);

ViStatus _VI_FUNC rsngx_QueryBatterySimulatorCondition(ViSession instrSession,
                                                       ViInt32   channel,
                                                       ViInt32*  batteryStatus,
                                                       ViReal64* remainingCapacity,
                                                       ViReal64* terminalVoltage,
                                                       ViReal64* internalResistance,
                                                       ViReal64* current);

ViStatus _VI_FUNC rsngx_QueryBatterySimulatorVOCStats(ViSession instrSession,
                                                      ViInt32   channel,
                                                      ViReal64* opencircuitVoltage,
                                                      ViReal64* emptyOpencircuitVoltage,
                                                      ViReal64* fullOpencircuitVoltage);

ViStatus _VI_FUNC rsngx_ConfigureBatterySimulatorLimits(ViSession instrSession,
                                                        ViReal64  endOfCharge,
                                                        ViReal64  endOfDischarge,
                                                        ViReal64  regularChargeLevel);

ViStatus _VI_FUNC rsngx_ConfigureBatteryModelLimits(ViSession instrSession,
                                                    ViReal64  endOfCharge,
                                                    ViReal64  endOfDischarge,
                                                    ViReal64  regularChargeLevel);

ViStatus _VI_FUNC rsngx_ConfigureBrightness(ViSession instrSession,
                                            ViReal64  brightness,
                                            ViReal64  frontPanelKeyBrightness);

ViStatus _VI_FUNC rsngx_ShowMessageBox(ViSession instrSession,
                                       ViString  text);

ViStatus _VI_FUNC rsngx_ClearMessageBox(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureSystemTouchEnabled(ViSession instrSession,
                                                    ViInt32   touchscreenEnabled);

ViStatus _VI_FUNC rsngx_ConfigureTriggerSettings(ViSession instrSession,
                                                 ViBoolean triggerEnabled,
                                                 ViInt32   source,
                                                 ViInt32   outputChannel,
                                                 ViInt32   operationMode);

ViStatus _VI_FUNC rsngx_ConfigureTriggerDIOPin(ViSession instrSession,
                                               ViInt32   DIOPin);

ViStatus _VI_FUNC rsngx_ConfigureTriggerSlope(ViSession instrSession,
                                              ViInt32   triggerSlope);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerEnabled(ViSession instrSession,
                                                         ViInt32   enabled);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerLine(ViSession instrSession,
                                                      ViInt32   line,
                                                      ViInt32   enabled,
                                                      ViInt32   direction);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerLineMode(ViSession instrSession,
                                                          ViInt32   line,
                                                          ViInt32   mode,
                                                          ViReal64  value);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerLineLogic(ViSession instrSession,
                                                           ViInt32   line,
                                                           ViInt32   activeLevel);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerLineChannel(ViSession instrSession,
                                                             ViInt32   line,
                                                             ViInt32   channel);

ViStatus _VI_FUNC rsngx_ConfigureDigitalIOTriggerLineDIOEnabled(
                            ViSession instrSession,
                            ViInt32   line,
                            ViInt32   enabled);

ViStatus _VI_FUNC rsngx_ImageSnapshot(ViSession instrSession,
                                      ViString  destination);

ViStatus _VI_FUNC rsngx_QueryImageSize(ViSession instrSession,
                                       ViInt32*  imageWidth,
                                       ViInt32*  imageHeight);

ViStatus _VI_FUNC rsngx_QueryGPIBInterfaceInfo(ViSession instrSession,
                                               ViUInt32  bufferSize,
                                               ViChar    interfaceInfo[]);

ViStatus _VI_FUNC rsngx_QueryAvailableSystemInterface(ViSession instrSession,
                                                      ViUInt32  bufferSize,
                                                      ViChar    availableSystemInterface[]);

ViStatus _VI_FUNC rsngx_ConfigureLANNetworkSettings(ViSession instrSession,
                                                    ViInt32   DHCPEnabled,
                                                    ViString  IPAddress,
                                                    ViString  subnetMask,
                                                    ViString  gateway);

ViStatus _VI_FUNC rsngx_ConfigureInterfaceUSBClass(ViSession instrSession,
                                                   ViInt32   USBClass);

ViStatus _VI_FUNC rsngx_ApplyLANNetworkSettings(ViSession instrSession);

ViStatus _VI_FUNC rsngx_DiscardLANSettings(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ResetLANSettings(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureLANHostname(ViSession instrSession,
                                             ViString  hostname);

ViStatus _VI_FUNC rsngx_QueryLANMACAddress(ViSession instrSession,
                                           ViChar    MACAddress[]);

ViStatus _VI_FUNC rsngx_QueryLANEditedMode(ViSession  instrSession,
                                           ViBoolean* editedMode);

ViStatus _VI_FUNC rsngx_ConfigureWLANEnabled(ViSession instrSession,
                                             ViInt32   enabled);

ViStatus _VI_FUNC rsngx_ConfigureWLANConnectionEnabled(ViSession instrSession,
                                                       ViInt32   connectionEnabled);

ViStatus _VI_FUNC rsngx_ConfigureWLANSSID(ViSession instrSession,
                                          ViString  SSID);

ViStatus _VI_FUNC rsngx_ConfigureWLANPassword(ViSession instrSession,
                                              ViString  password);

ViStatus _VI_FUNC rsngx_ConfigureWLANNetworkSettings(ViSession instrSession,
                                                     ViInt32   DHCPEnabled,
                                                     ViString  reserved,
                                                     ViString  subnetMask,
                                                     ViString  gateway);

ViStatus _VI_FUNC rsngx_QueryWLANIPAddress(ViSession instrSession,
                                           ViChar    IPAddress[]);

ViStatus _VI_FUNC rsngx_ApplyWLANNetworkSettings(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureVNCSettings(ViSession instrSession,
                                             ViBoolean VNC,
                                             ViInt32   port);

ViStatus _VI_FUNC rsngx_ConfigureSoundBeeperSettings(ViSession instrSession,
                                                     ViBoolean errorBeepEnabled,
                                                     ViInt32   trippedBeepEnabled,
                                                     ViInt32   continuousBeepEnabled);

ViStatus _VI_FUNC rsngx_GetSoundBeep(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureSoundCompleteBeepEnabled(ViSession instrSession,
                                                          ViBoolean completeBeep);

ViStatus _VI_FUNC rsngx_GetSoundCompleteBeep(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureSoundWarningBeepEnabled(ViSession instrSession,
                                                         ViBoolean warningBeep);

ViStatus _VI_FUNC rsngx_GetSoundWarningBeep(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ConfigureSoundOutputBeepEnabled(ViSession instrSession,
                                                        ViBoolean outputBeep);

ViStatus _VI_FUNC rsngx_SetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeId,
                                            ViInt32   attributeValue);

ViStatus _VI_FUNC rsngx_SetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeId,
                                            ViInt64   attributeValue);

ViStatus _VI_FUNC rsngx_SetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeId,
                                             ViReal64  attributeValue);

ViStatus _VI_FUNC rsngx_SetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeId,
                                             ViString  attributeValue);

ViStatus _VI_FUNC rsngx_SetAttributeViBoolean(ViSession instrSession,
                                              ViString  repeatedCapabilityName,
                                              ViAttr    attributeId,
                                              ViBoolean attributeValue);

ViStatus _VI_FUNC rsngx_GetAttributeViInt32(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeId,
                                            ViInt32*  attributeValue);

ViStatus _VI_FUNC rsngx_GetAttributeViInt64(ViSession instrSession,
                                            ViString  repeatedCapabilityName,
                                            ViAttr    attributeId,
                                            ViInt64*  attributeValue);

ViStatus _VI_FUNC rsngx_GetAttributeViReal64(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeId,
                                             ViReal64* attributeValue);

ViStatus _VI_FUNC rsngx_GetAttributeViString(ViSession instrSession,
                                             ViString  repeatedCapabilityName,
                                             ViAttr    attributeId,
                                             ViInt32   bufferSize,
                                             ViChar    attributeValue[]);

ViStatus _VI_FUNC rsngx_GetAttributeViBoolean(ViSession  instrSession,
                                              ViString   repeatedCapabilityName,
                                              ViAttr     attributeId,
                                              ViBoolean* attributeValue);

ViStatus _VI_FUNC rsngx_GetAttributeViStringWithRealLen(ViSession instrSession,
                                                        ViString  repeatedCapability,
                                                        ViAttr    attributeId,
                                                        ViInt32   bufferSize,
                                                        ViChar    attributeValue[],
                                                        ViInt32*  responseLength);

ViStatus _VI_FUNC rsngx_GetAttributeRawStringWithRealLen(ViSession instrSession,
                                                         ViString  repeatedCapability,
                                                         ViAttr    attributeId,
                                                         ViInt32   bufferSize,
                                                         ViChar    attributeValue[],
                                                         ViInt32*  responseLength);

ViStatus _VI_FUNC rsngx_GetAttributeRepCapName(ViSession instrSession,
                                               ViAttr    attributeId,
                                               ViString  repCapNameID,
                                               ViInt32   index,
                                               ViInt32   bufferSize,
                                               ViChar    repCapName[]);

ViStatus _VI_FUNC rsngx_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                          ViAttr    attributeId,
                                                          ViInt32   bufferSize,
                                                          ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rsngx_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rsngx_reset(ViSession instrSession);

ViStatus _VI_FUNC rsngx_self_test(ViSession instrSession,
                                  ViInt16*  selfTestResult,
                                  ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rsngx_revision_query(ViSession instrSession,
                                       ViChar    instrumentDriverRevision[],
                                       ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsngx_BeeperEnabled(ViSession instrSession,
                                      ViBoolean beeperState);

ViStatus _VI_FUNC rsngx_SystemLocal(ViSession instrSession);

ViStatus _VI_FUNC rsngx_SystemRemote(ViSession instrSession);

ViStatus _VI_FUNC rsngx_SystemRWLock(ViSession instrSession);

ViStatus _VI_FUNC rsngx_ManageInstrumentSettings(ViSession instrSession,
                                                 ViInt32   operation,
                                                 ViInt32   internalMemory);

ViStatus _VI_FUNC rsngx_error_query(ViSession instrSession,
                                    ViInt32*  errorCode,
                                    ViChar    errorMessage[]);

ViStatus _VI_FUNC rsngx_error_message(ViSession instrSession,
                                      ViStatus  errorCode,
                                      ViChar    errorMessage[]);

ViStatus _VI_FUNC rsngx_SetStatusRegister(ViSession instrSession,
                                          ViInt32   registerGroup,
                                          ViInt32   registerType,
                                          ViInt32   registerValue);

ViStatus _VI_FUNC rsngx_GetStatusRegister(ViSession instrSession,
                                          ViInt32   registerGroup,
                                          ViInt32   registerType,
                                          ViInt32*  registerValue);

ViStatus _VI_FUNC rsngx_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsngx_SaveSystemSettingsFile(ViSession instrSession,
                                               ViString  path);

ViStatus _VI_FUNC rsngx_RestartInstrument(ViSession instrSession);

ViStatus _VI_FUNC rsngx_QuerySystemUptime(ViSession instrSession,
                                          ViReal64* uptime);

ViStatus _VI_FUNC rsngx_IDQueryResponse(ViSession instrSession,
                                        ViInt32   bufferSize,
                                        ViChar    IDQueryResponse[],
                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsngx_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsngx_QueryOPC(ViSession instrSession,
                                 ViInt32*  OPC);

ViStatus _VI_FUNC rsngx_ConfigureErrorChecking(ViSession instrSession,
                                               ViBoolean optionChecking,
                                               ViBoolean rangeChecking,
                                               ViBoolean statusChecking);

ViStatus _VI_FUNC rsngx_SetVISATimeout(ViSession instrSession,
                                       ViUInt32  VISATimeout);

ViStatus _VI_FUNC rsngx_GetVISATimeout(ViSession instrSession,
                                       ViUInt32* VISATimeout);

ViStatus _VI_FUNC rsngx_SetOPCTimeout(ViSession instrSession,
                                      ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rsngx_GetOPCTimeout(ViSession instrSession,
                                      ViUInt32* timeout);

ViStatus _VI_FUNC rsngx_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                    ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsngx_ConfigureMultiThreadLocking(ViSession instrSession,
                                                    ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rsngx_InstrumentOptions(ViSession instrSession,
                                          ViInt32   bufferSize,
                                          ViChar    options[],
                                          ViInt32*  bytesRead);

ViStatus _VI_FUNC rsngx_HasOptionInstalled(ViSession  instrSession,
                                           ViString   option,
                                           ViBoolean* installed);

ViStatus _VI_FUNC rsngx_GetError(ViSession instrSession,
                                 ViStatus* code,
                                 ViInt32   bufferSize,
                                 ViChar    description[]);

ViStatus _VI_FUNC rsngx_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsngx_Write(ViSession instrSession,
                              ViString  writeBuffer);

ViStatus _VI_FUNC rsngx_QueryViBoolean(ViSession  instrSession,
                                       ViString   command,
                                       ViBoolean* value);

ViStatus _VI_FUNC rsngx_QueryViInt32(ViSession instrSession,
                                     ViString  command,
                                     ViInt32*  value);

ViStatus _VI_FUNC rsngx_QueryViReal64(ViSession instrSession,
                                      ViString  command,
                                      ViReal64* value);

ViStatus _VI_FUNC rsngx_QueryViString(ViSession instrSession,
                                      ViString  command,
                                      ViInt32   bufferSize,
                                      ViChar    value[]);

ViStatus _VI_FUNC rsngx_WriteCommandWithOPCSync(ViSession instrSession,
                                                ViString  writeBuffer,
                                                ViInt32   timeout);

ViStatus _VI_FUNC rsngx_close(ViSession instrSession);

    /****************************************************************************
     *------------------------ Error And Completion Codes ----------------------*
     ****************************************************************************/

#define RSNGX_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSNGX_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)
#define RSNGX_WARN_DATA_NOT_AVAILABLE      (RS_CLASS_WARN_BASE + 0x0003L)

#define RSNGX_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSNGX_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSNGX_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSNGX_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSNGX_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSNGX_WARNMSG_OVER_RANGE           "Measurement overrange"
#define RSNGX_WARNMSG_DATA_NOT_AVAILABLE   "Measurement data not available"

#define RSNGX_ERRMSG_INCORRECT_STATE       "Instrument in incorrect state"
#define RSNGX_ERRMSG_INCORRECT_RESPONSE    "Response incorrect; report problem to R&S support!"
#define RSNGX_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSNGX_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSNGX_ERROR_CODES_AND_MSGS \
    {RSNGX_ERROR_INCORRECT_STATE,   RSNGX_ERRMSG_INCORRECT_STATE},\
    {RSNGX_ERROR_INCORRECT_RESPONSE,     RSNGX_ERRMSG_INCORRECT_RESPONSE},\
    {RSNGX_WARN_DATA_NOT_AVAILABLE,    RSNGX_WARNMSG_DATA_NOT_AVAILABLE},\
    {RSNGX_ERROR_MAX_TIME_EXCEEDED,    RSNGX_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSNGX_ERROR_RELIABILITY_INDICATOR,    RSNGX_ERRMSG_RELIABILITY_INDICATOR}

     /****************************************************************************
      *---------------------------- End Include File ----------------------------*
      ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSNGX_HEADER */